# Generated by Django 3.1.5 on 2021-01-11 10:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


def populate_auth_groups_clients_mapping_name_field(apps, schema_editor):
    AuthGroupsClientsMapping = apps.get_model("cri_auth", "AuthGroupsClientsMapping")
    OIDCClientExtension = apps.get_model("cri_auth", "OIDCClientExtension")
    db_alias = schema_editor.connection.alias

    for agcm in AuthGroupsClientsMapping.objects.using(db_alias).all():
        clients = []
        oice = OIDCClientExtension.objects.using(db_alias).filter(
            groups_clients_mapping=agcm
        )
        if oice:
            clients.extend(map(lambda x: x.client.name + " (OIDC)", oice))
        if not clients:
            agcm.name = "-"
        else:
            agcm.name = ", ".join(clients)
        agcm.save()


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("cri_auth", "0007_auto_20210503_1128"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="OIDCClientExtensionGroup",
            new_name="AuthGroup",
        ),
        migrations.RenameModel(
            old_name="OIDCClientExtension",
            new_name="AuthGroupsClientsMapping",
        ),
        migrations.RenameField(
            model_name="AuthGroup",
            old_name="oidc_client_extension",
            new_name="groups_clients_mapping",
        ),
        migrations.RenameField(
            model_name="AuthGroup",
            old_name="client_can_see_private_subgroups",
            new_name="clients_can_see_private_subgroups",
        ),
        migrations.RenameField(
            model_name="AuthGroup",
            old_name="group_managers_can_manage_client",
            new_name="group_managers_can_manage_clients",
        ),
        migrations.AlterField(
            model_name="AuthGroup",
            name="groups_clients_mapping",
            field=models.ForeignKey(
                on_delete=models.CASCADE,
                to="cri_auth.authgroupsclientsmapping",
            ),
        ),
        migrations.AddField(
            model_name="AuthGroupsClientsMapping",
            name="name",
            field=models.CharField(max_length=100, default="Placeholder"),
            preserve_default=False,
        ),
        migrations.CreateModel(
            name="OIDCClientExtension",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "client",
                    models.OneToOneField(
                        on_delete=models.CASCADE, to="oidc_provider.client"
                    ),
                ),
                (
                    "groups_clients_mapping",
                    models.ForeignKey(
                        on_delete=models.PROTECT,
                        to="cri_auth.authgroupsclientsmapping",
                    ),
                ),
                (
                    "is_legacy",
                    models.BooleanField(
                        default=False,
                        help_text="If enabled, the claims returned by the epita scope will match the old OIDC API. Do not use for new OIDC clients.",
                    ),
                ),
            ],
        ),
        migrations.RunSQL(
            sql="""
                INSERT INTO cri_auth_oidcclientextension (client_id, groups_clients_mapping_id, is_legacy)
                SELECT client_id, id, is_legacy
                FROM cri_auth_authgroupsclientsmapping
            """,
            reverse_sql=migrations.RunSQL.noop,
            elidable=True,
        ),
        migrations.RemoveField(
            model_name="authgroupsclientsmapping",
            name="client",
        ),
        migrations.RemoveField(
            model_name="authgroupsclientsmapping",
            name="is_legacy",
        ),
        migrations.RunPython(
            code=populate_auth_groups_clients_mapping_name_field,
            reverse_code=(lambda *args: None),
            elidable=True,
        ),
        migrations.AlterModelOptions(
            name="authgroupsclientsmapping",
            options={},
        ),
        migrations.AlterModelOptions(
            name="oidcclientextension",
            options={"verbose_name": "OIDC client extension"},
        ),
    ]
