"""cri_intranet URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/2.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""

from django.contrib import admin
from django.conf import settings
from django.urls import include, path, re_path

from rest_framework import permissions
from drf_yasg.views import get_schema_view
from drf_yasg import openapi

schema_view = get_schema_view(
    openapi.Info(
        title="CRI API",
        default_version="v2.0-alpha",
        # description="Test description",
        contact=openapi.Contact(email="tickets@cri.epita.fr"),
        # license=openapi.License(name="BSD License"),
    ),
    validators=["ssv"],
    public=False,
    permission_classes=(permissions.AllowAny,),
    patterns=[path("api/v2/", include("cri_api.urls"))],
)

urlpatterns = [
    path("auth/", include("cri_auth.urls")),
    path("admin/", admin.site.urls),
    path("api/v2/", include("cri_api.urls")),
    path("api-auth/", include("rest_framework.urls")),
    re_path(
        r"swagger(?P<format>\.json|\.yaml)$",
        schema_view.without_ui(cache_timeout=0),
        name="schema-json",
    ),
    path(
        "swagger/",
        schema_view.with_ui("swagger", cache_timeout=0),
        name="schema-swagger-ui",
    ),
    path(
        "redoc/",
        schema_view.with_ui("redoc", cache_timeout=0),
        name="schema-redoc",
    ),
    path("cards/", include("cri_cards.urls")),
    path("", include("cri_frontend.urls")),
    path("", include("oidc_provider.urls", namespace="oidc_provider")),
]

if settings.DEBUG and not settings.TESTING:
    import debug_toolbar

    urlpatterns = [path("__debug__/", include(debug_toolbar.urls))] + urlpatterns
