# Generated by Django 3.0.1 on 2020-04-23 16:35

import cri_models.fields
import cri_models.kerberos.fields
import cri_models.ldap
import cri_models.ldap.user
import cri_models.sync.kerberosmodelengine
import cri_models.sync.ldapmodelengine
from django.conf import settings
import django.contrib.auth.models
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    initial = True

    dependencies = [("auth", "0011_update_proxy_permissions")]

    operations = [
        migrations.CreateModel(
            name="CRIUser",
            fields=[
                (
                    "password",
                    models.CharField(max_length=128, verbose_name="password"),
                ),
                (
                    "last_login",
                    models.DateTimeField(
                        blank=True, null=True, verbose_name="last login"
                    ),
                ),
                (
                    "is_superuser",
                    models.BooleanField(
                        default=False,
                        help_text="Designates that this user has all permissions without explicitly assigning them.",
                        verbose_name="superuser status",
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        blank=True,
                        max_length=254,
                        verbose_name="email address",
                    ),
                ),
                (
                    "is_staff",
                    models.BooleanField(
                        default=False,
                        help_text="Designates whether the user can log into this admin site.",
                        verbose_name="staff status",
                    ),
                ),
                (
                    "is_active",
                    models.BooleanField(
                        default=True,
                        help_text="Designates whether this user should be treated as active. Unselect this instead of deleting accounts.",
                        verbose_name="active",
                    ),
                ),
                (
                    "date_joined",
                    models.DateTimeField(
                        default=django.utils.timezone.now,
                        verbose_name="date joined",
                    ),
                ),
                (
                    "username",
                    models.CharField(max_length=100, primary_key=True, serialize=False),
                ),
                (
                    "first_name",
                    models.CharField(
                        blank=True,
                        help_text="commonly used first name",
                        max_length=100,
                    ),
                ),
                (
                    "last_name",
                    models.CharField(
                        blank=True,
                        help_text="commonly used last name",
                        max_length=100,
                    ),
                ),
                (
                    "legal_first_name",
                    models.CharField(
                        blank=True,
                        help_text="first name to be used on legal documents",
                        max_length=100,
                    ),
                ),
                (
                    "legal_last_name",
                    models.CharField(
                        blank=True,
                        help_text="last name to be used on legal documents",
                        max_length=100,
                    ),
                ),
                (
                    "uid",
                    cri_models.fields.UnixIDField(
                        help_text="Unix user ID",
                        unique=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(65535),
                        ],
                        verbose_name="UID",
                    ),
                ),
                ("birthdate", models.DateField(blank=True, null=True)),
                (
                    "phone",
                    phonenumber_field.modelfields.PhoneNumberField(
                        blank=True,
                        help_text="Mobile phone number",
                        max_length=128,
                        null=True,
                        region=None,
                    ),
                ),
                (
                    "ldap_dn",
                    cri_models.ldap.LDAPDNField(
                        cri_models.ldap.user.LDAPUser,
                        blank=True,
                        max_length=254,
                        null=True,
                        unique=True,
                        verbose_name="LDAP DN",
                    ),
                ),
                (
                    "groups",
                    models.ManyToManyField(
                        blank=True,
                        help_text="The groups this user belongs to. A user will get all permissions granted to each of their groups.",
                        related_name="user_set",
                        related_query_name="user",
                        to="auth.Group",
                        verbose_name="groups",
                    ),
                ),
                (
                    "old_account",
                    models.OneToOneField(
                        blank=True,
                        help_text="Past account of this user",
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="new_account",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI User",
                "verbose_name_plural": "CRI Users",
                "permissions": (
                    ("impersonate", "Can impersonate users"),
                    ("update_criuser_passwords", "Can change passwords"),
                    ("view_criuser_personal_data", "Can view personal data"),
                    ("update_criuser_phone", "can view phone numbers"),
                    ("update_criuser_birthdate", "Can view birthdate"),
                ),
                "abstract": False,
            },
            bases=(models.Model,),
            managers=[("objects", django.contrib.auth.models.UserManager())],
        ),
        migrations.CreateModel(
            name="CRIGroup",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("slug", models.SlugField(unique=True)),
                (
                    "gid",
                    cri_models.fields.UnixIDField(
                        blank=True,
                        help_text="Unix group ID",
                        null=True,
                        unique=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(65535),
                        ],
                        verbose_name="GID",
                    ),
                ),
                ("name", models.CharField(max_length=128)),
                (
                    "kind",
                    models.CharField(
                        choices=[
                            ("assistant", "assistant"),
                            ("association", "association"),
                            ("campus", "campus"),
                            ("class", "class"),
                            ("course", "course"),
                            ("curriculum", "curriculum"),
                            ("department", "department"),
                            ("laboratory", "laboratory"),
                            ("major", "major"),
                            ("other", "other"),
                            ("semester", "semester"),
                            ("year", "year"),
                        ],
                        default="class",
                        max_length=128,
                    ),
                ),
                (
                    "private",
                    models.BooleanField(
                        default=False,
                        help_text="If true this group will only be shown to its members",
                    ),
                ),
                (
                    "children",
                    models.ManyToManyField(
                        blank=True,
                        related_name="parents",
                        to="cri_models.CRIGroup",
                    ),
                ),
                (
                    "computed_children",
                    models.ManyToManyField(
                        blank=True,
                        editable=False,
                        related_name="computed_parents",
                        to="cri_models.CRIGroup",
                    ),
                ),
                (
                    "managers",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Users allowed to manage this group",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "next_group",
                    models.ForeignKey(
                        blank=True,
                        help_text="Group into which to move the current group members at the end of the their membership",
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="previous_groups",
                        to="cri_models.CRIGroup",
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI Group",
                "ordering": ("kind", "name", "slug"),
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="KerberosPrincipal",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "principal",
                    cri_models.kerberos.fields.KerberosPrincipalField(
                        max_length=100, unique=True
                    ),
                ),
                ("out_of_date", models.BooleanField(default=True)),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="CRIMembership",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "graduation_year",
                    cri_models.fields.GraduationYearField(
                        blank=True,
                        null=True,
                        validators=[django.core.validators.MinValueValidator(1989)],
                    ),
                ),
                ("begin_at", models.DateField()),
                ("end_at", models.DateField(blank=True, null=True)),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cri_models.CRIGroup",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI Membership history",
                "verbose_name_plural": "CRI Membership history",
            },
        ),
        migrations.CreateModel(
            name="CRIComputedMembership",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "graduation_year",
                    cri_models.fields.GraduationYearField(
                        blank=True,
                        null=True,
                        validators=[django.core.validators.MinValueValidator(1989)],
                    ),
                ),
                ("begin_at", models.DateField()),
                ("end_at", models.DateField(blank=True, null=True)),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cri_models.CRIGroup",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="memberships",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI computed memberships",
                "verbose_name_plural": "CRI computed memberships",
            },
        ),
        migrations.CreateModel(
            name="Campus",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "group",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cri_models.CRIGroup",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "campuses",
                "ordering": ("group__name",),
            },
        ),
        migrations.AddField(
            model_name="criuser",
            name="primary_group",
            field=models.ForeignKey(
                default=1,
                limit_choices_to={"gid__isnull": False},
                on_delete=django.db.models.deletion.SET_DEFAULT,
                related_name="primary_group_user",
                to="cri_models.CRIGroup",
            ),
        ),
        migrations.AddField(
            model_name="criuser",
            name="primary_principal",
            field=models.ForeignKey(
                blank=True,
                help_text="Primary kerberos principal of this user",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="cri_models.KerberosPrincipal",
            ),
        ),
        migrations.AddField(
            model_name="criuser",
            name="user_permissions",
            field=models.ManyToManyField(
                blank=True,
                help_text="Specific permissions for this user.",
                related_name="user_set",
                related_query_name="user",
                to="auth.Permission",
                verbose_name="user permissions",
            ),
        ),
        migrations.CreateModel(
            name="CRICurrentComputedMembership",
            fields=[],
            options={
                "verbose_name": "CRI current computed membership",
                "verbose_name_plural": "CRI current computed membership",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("cri_models.cricomputedmembership",),
        ),
        migrations.CreateModel(
            name="SSHPublicKey",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "title",
                    models.CharField(blank=True, max_length=128, unique=True),
                ),
                (
                    "key",
                    cri_models.fields.SSHPublicKeyField(
                        unique=True,
                        validators=[
                            cri_models.fields.SSHPublicKeyField.sshpubkey_validator,
                            cri_models.fields.SSHPublicKeyField.sshpubkey_validator,
                            cri_models.fields.SSHPublicKeyField.sshpubkey_validator,
                        ],
                    ),
                ),
                ("key_type", models.CharField(editable=False, max_length=32)),
                ("key_length", models.PositiveIntegerField(editable=False)),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "SSH public key",
                "ordering": ("user", "title"),
                "unique_together": {("user", "title")},
            },
        ),
    ]
