# Generated by Django 3.1.7 on 2021-07-30 08:33

from django.db import migrations, models


# pylint: disable=unused-argument
def convert_user_mail_aliases_to_manytomany(apps, schema_editor):
    MailAlias = apps.get_model("cri_models", "MailAlias")

    data = {}
    for alias in MailAlias.objects.filter(user__isnull=False):
        data.setdefault(alias.email, []).append(alias.user)

    MailAlias.objects.all().delete()

    newaliases = MailAlias.objects.bulk_create(MailAlias(email=e) for e in data.keys())
    for alias in newaliases:
        for user in data[alias.email]:
            user.mail_aliases.add(alias)


# pylint: disable=unused-argument
def convert_user_mail_aliases_from_manytomany(apps, schema_editor):
    MailAlias = apps.get_model("cri_models", "MailAlias")
    CRIUser = apps.get_model("cri_models", "CRIUser")

    data = []
    for user in CRIUser.objects.exclude(mail_aliases=None):
        for alias in set(user.mail_aliases.all()):
            data.append(MailAlias(email=alias.email, user=user))
    MailAlias.objects.all().delete()
    MailAlias.objects.bulk_create(data)


class Migration(migrations.Migration):

    dependencies = [("cri_models", "0013_auto_20210712_1447")]

    operations = [
        migrations.AlterModelOptions(
            name="mailalias",
            options={"ordering": ("email",), "verbose_name_plural": "mail aliases"},
        ),
        migrations.AddField(
            model_name="criuser",
            name="mail_aliases",
            field=models.ManyToManyField(
                blank=True,
                help_text="Mail aliases that can be used by this user",
                to="cri_models.MailAlias",
            ),
        ),
        migrations.AlterUniqueTogether(name="mailalias", unique_together=set()),
        migrations.RunSQL(
            "SET CONSTRAINTS ALL IMMEDIATE;", "SET CONSTRAINTS ALL DEFERRED;"
        ),
        migrations.RunPython(
            convert_user_mail_aliases_to_manytomany,
            convert_user_mail_aliases_from_manytomany,
        ),
        migrations.RunSQL(
            "SET CONSTRAINTS ALL DEFERRED;", "SET CONSTRAINTS ALL IMMEDIATE;"
        ),
        migrations.AlterField(
            model_name="mailalias",
            name="email",
            field=models.EmailField(max_length=254, unique=True),
        ),
        migrations.RemoveField(model_name="mailalias", name="user"),
    ]
