# Generated by Django 3.2.16 on 2022-10-27 15:10

import cri_intranet.custom_storage
import cri_models.fields
import cri_models.models.criuser
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


# pylint: disable=unused-argument
def add_criuserpreference_to_all_users(apps, schema_editor):
    users = apps.get_model("cri_models.CRIUser")
    preferences = apps.get_model("cri_models.CRIUserPreference")
    to_create = []
    for u in users.objects.all():
        if not preferences.objects.filter(user=u):
            to_create.append(preferences(user=u))
    preferences.objects.bulk_create(to_create)


# pylint: disable=unused-argument
def remove_all_criuserprefrence(apps, schema_editor):
    preferences = apps.get_model("cri_models.CRIUserPreference")
    preferences.objects.all().delete()


class Migration(migrations.Migration):

    dependencies = [
        ("cri_models", "0019_auto_20211024_2304"),
    ]

    operations = [
        migrations.CreateModel(
            name="CRIPhotoKind",
            fields=[
                (
                    "name",
                    models.CharField(max_length=20, primary_key=True, serialize=False),
                ),
                ("priority", models.SmallIntegerField()),
            ],
            options={
                "verbose_name": "CRI Photo Kind",
                "verbose_name_plural": "CRI Photo Kinds",
            },
        ),
        migrations.AlterModelOptions(
            name="criuser",
            options={
                "ordering": ("username",),
                "permissions": (
                    ("impersonate", "Can impersonate users"),
                    ("view_criuser_legal_identity", "Can view legal identies"),
                    ("view_criuser_phone", "can view phone numbers"),
                    ("view_criuser_birthdate", "Can view birthdates"),
                    ("update_criuser_password", "Can change passwords"),
                    ("export_data", "Can export user data"),
                    ("view_criuser_photo", "Can view all photos"),
                ),
                "verbose_name": "CRI User",
                "verbose_name_plural": "CRI Users",
            },
        ),
        migrations.CreateModel(
            name="CRIUserPreference",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "photo_visibility",
                    models.IntegerField(
                        choices=[(1, "Private"), (2, "Internal"), (3, "Public")],
                        default=2,
                    ),
                ),
                (
                    "user",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI User Preference",
            },
        ),
        migrations.CreateModel(
            name="CRIPhoto",
            fields=[
                (
                    "uuid",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "image",
                    models.ImageField(
                        storage=cri_intranet.custom_storage.PhotoStorage,
                        upload_to=cri_models.models.criuser.CRIPhoto.get_photo_path,
                    ),
                ),
                (
                    "image_thumb",
                    models.ImageField(
                        blank=True,
                        editable=False,
                        storage=cri_intranet.custom_storage.PhotoStorage,
                        upload_to=cri_models.models.criuser.CRIPhoto.get_photo_thumb_path,
                    ),
                ),
                (
                    "image_square",
                    models.ImageField(
                        blank=True,
                        storage=cri_intranet.custom_storage.PhotoStorage,
                        upload_to=cri_models.models.criuser.CRIPhoto.get_photo_square_path,
                    ),
                ),
                ("priority", models.SmallIntegerField(blank=True)),
                (
                    "kind",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cri_models.criphotokind",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "CRI Photo",
                "verbose_name_plural": "CRI Photos",
            },
        ),
        migrations.RunPython(
            add_criuserpreference_to_all_users, reverse_code=remove_all_criuserprefrence
        ),
    ]
